@@ -1348,14 +1348,14 @@ var require_templates = __commonJS({
       }
       return results;
     }
-    function buildStyle(chalk3, styles) {
+    function buildStyle(chalk2, styles) {
       const enabled2 = {};
       for (const layer of styles) {
         for (const style of layer.styles) {
           enabled2[style[0]] = layer.inverse ? null : style.slice(1);
         }
       }
-      let current = chalk3;
+      let current = chalk2;
       for (const [styleName, styles2] of Object.entries(enabled2)) {
         if (!Array.isArray(styles2)) {
           continue;
@@ -1367,7 +1367,7 @@ var require_templates = __commonJS({
       }
       return current;
     }
-    module2.exports = (chalk3, temporary) => {
+    module2.exports = (chalk2, temporary) => {
       const styles = [];
       const chunks = [];
       let chunk = [];
@@ -1377,13 +1377,13 @@ var require_templates = __commonJS({
         } else if (style) {
           const string = chunk.join("");
           chunk = [];
-          chunks.push(styles.length === 0 ? string : buildStyle(chalk3, styles)(string));
+          chunks.push(styles.length === 0 ? string : buildStyle(chalk2, styles)(string));
           styles.push({ inverse, styles: parseStyle(style) });
         } else if (close) {
           if (styles.length === 0) {
             throw new Error("Found extraneous } in Chalk template literal");
           }
-          chunks.push(buildStyle(chalk3, styles)(chunk.join("")));
+          chunks.push(buildStyle(chalk2, styles)(chunk.join("")));
           chunk = [];
           styles.pop();
         } else {
@@ -1431,16 +1431,16 @@ var require_source = __commonJS({
       }
     };
     var chalkFactory = (options) => {
-      const chalk4 = {};
-      applyOptions(chalk4, options);
-      chalk4.template = (...arguments_) => chalkTag(chalk4.template, ...arguments_);
-      Object.setPrototypeOf(chalk4, Chalk.prototype);
-      Object.setPrototypeOf(chalk4.template, chalk4);
-      chalk4.template.constructor = () => {
+      const chalk3 = {};
+      applyOptions(chalk3, options);
+      chalk3.template = (...arguments_) => chalkTag(chalk3.template, ...arguments_);
+      Object.setPrototypeOf(chalk3, Chalk.prototype);
+      Object.setPrototypeOf(chalk3.template, chalk3);
+      chalk3.template.constructor = () => {
         throw new Error("`chalk.constructor()` is deprecated. Use `new chalk.Instance()` instead.");
       };
-      chalk4.template.Instance = ChalkClass;
-      return chalk4.template;
+      chalk3.template.Instance = ChalkClass;
+      return chalk3.template;
     };
     function Chalk(options) {
       return chalkFactory(options);
@@ -1551,7 +1551,7 @@ var require_source = __commonJS({
       return openAll + string + closeAll;
     };
     var template;
-    var chalkTag = (chalk4, ...strings) => {
+    var chalkTag = (chalk3, ...strings) => {
       const [firstString] = strings;
       if (!isArray(firstString) || !isArray(firstString.raw)) {
         return strings.join(" ");
@@ -1567,14 +1567,14 @@ var require_source = __commonJS({
       if (template === void 0) {
         template = require_templates();
       }
-      return template(chalk4, parts.join(""));
+      return template(chalk3, parts.join(""));
     };
     Object.defineProperties(Chalk.prototype, styles);
-    var chalk3 = Chalk();
-    chalk3.supportsColor = stdoutColor;
-    chalk3.stderr = Chalk({ level: stderrColor ? stderrColor.level : 0 });
-    chalk3.stderr.supportsColor = stderrColor;
-    module2.exports = chalk3;
+    var chalk2 = Chalk();
+    chalk2.supportsColor = stdoutColor;
+    chalk2.stderr = Chalk({ level: stderrColor ? stderrColor.level : 0 });
+    chalk2.stderr.supportsColor = stderrColor;
+    module2.exports = chalk2;
   }
 });
 
@@ -1590,7 +1590,7 @@ var import_os = require("os");
 var import_path = require("path");
 var path = __toESM(require("path"));
 var import_util = require("util");
-var chalk2 = __toESM(require_source());
+var import_chalk = __toESM(require_source());
 
 // src/common.ts
 var PROJEN_DIR = ".projen";
@@ -1671,9 +1671,7 @@ var RunTask = class {
     this.workdir = task.cwd ?? this.runtime.workdir;
     this.parents = parents;
     if (!task.steps || task.steps.length === 0) {
-      this.logDebug(
-        chalk2.gray("No actions have been specified for this task.")
-      );
+      this.logDebug((0, import_chalk.gray)("No actions have been specified for this task."));
       return;
     }
     this.env = this.resolveEnvironment(parents);
@@ -1684,9 +1682,7 @@ var RunTask = class {
       envlogs.push(`${k}=${trimmed}`);
     }
     if (envlogs.length) {
-      this.logDebug(
-        chalk2.gray(`${chalk2.underline("env")}: ${envlogs.join(" ")}`)
-      );
+      this.logDebug((0, import_chalk.gray)(`${(0, import_chalk.underline)("env")}: ${envlogs.join(" ")}`));
     }
     if (!this.evalCondition(task)) {
       this.log("condition exited with non-zero - skipping");
@@ -1769,7 +1765,7 @@ var RunTask = class {
     if (!task.condition) {
       return true;
     }
-    this.log(chalk2.gray(`${chalk2.underline("condition")}: ${task.condition}`));
+    this.log((0, import_chalk.gray)(`${(0, import_chalk.underline)("condition")}: ${task.condition}`));
     const result = this.shell({
       command: task.condition,
       logprefix: "condition: ",
@@ -1800,7 +1796,7 @@ var RunTask = class {
     };
     const output = {};
     for (const [key, value] of Object.entries(env ?? {})) {
-      if (value.startsWith("$(") && value.endsWith(")")) {
+      if (String(value).startsWith("$(") && String(value).endsWith(")")) {
         const query = value.substring(2, value.length - 1);
         const result = this.shellEval({ command: query });
         if (result.status !== 0) {
@@ -1829,7 +1825,7 @@ var RunTask = class {
     debug(this.fmtLog(...args));
   }
   fmtLog(...args) {
-    return (0, import_util.format)(`${chalk2.underline(this.fullname)} |`, ...args);
+    return (0, import_util.format)(`${(0, import_chalk.underline)(this.fullname)} |`, ...args);
   }
   shell(options) {
     const quiet = options.quiet ?? false;
